@@ -9,13 +9,12 @@ import logging
 
 import click
 
-from swh.core.cli import CONTEXT_SETTINGS, AliasedGroup
-
+from swh.core.cli import CONTEXT_SETTINGS, AliasedGroup, swh as swh_cli_group
 
 CFG_HELP = """Software Heritage Vault RPC server."""
 
 
-@click.group(name="vault", context_settings=CONTEXT_SETTINGS, cls=AliasedGroup)
+@swh_cli_group.group(name="vault", context_settings=CONTEXT_SETTINGS, cls=AliasedGroup)
 @click.pass_context
 def vault(ctx):
     """Software Heritage Vault tools."""
@@ -56,6 +55,7 @@ def vault(ctx):
 @click.pass_context
 def serve(ctx, config_file, no_stdout, host, port, debug):
     import aiohttp
+
     from swh.scheduler.celery_backend.config import setup_log_handler
     from swh.vault.api.server import make_app_from_configfile
 
